from . import helpers
import requests

# Pinterest API
PINTEREST_ENDPOINT = "http://api.pinterest.com/v1/urls/count.json?url="


def getPins(url):
	try:
		# Remove any URL tracking params
		url = helpers.removeParams(url)
		# Create Pinterest API URL
		target_url = PINTEREST_ENDPOINT + url
		# Hit Pinterest API
		r = requests.get(target_url)
		# Look for a "count" key
		if r.text.find("count") != -1:
			# Parse count value from response
			start = r.text.find('\"count\"')
			end = r.text.find(',', start+1)
			key_len = len('\"count\"')
			# Convert pin_count to integer
			pin_count = int(r.text[(start + key_len + 1):end].strip().replace('"',''))
			return { 'pin_count': pin_count }
		else:
			# Parse error
			start = r.text.find('\"error\"')
			end = r.text.find(',', start+1)
			key_len = len('\"error\"')
			# Return error message
			return { 'error': r.text[(start + key_len + 1):end].strip().replace('"', '') }
	except Exception as e:
		return { 'error': e }




from . import helpers
import requests

FACEBOOK_ENDPOINT = "http://graph.facebook.com/fql?format=json&q=SELECT%20share_count,%20like_count%20,%20comment_count%20FROM%20link_stat%20WHERE%20url="


def getTotalInteractions(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Encode URL
	url = helpers.encodeURL(url)
	# Create Facebook API URL
	target_url = FACEBOOK_ENDPOINT + '%27' + url + '%27'
	try:
		# Hit Facebook API
		r = requests.get(target_url)
		j = r.json()
		if j['data']:
			# Sum shares, likes, and comments
			return { 'total_count': sum(j['data'][0].values()) }
		else:
			return { 'error': j['error']['message'] }
	except Exception as e:
		return { 'error': e }


def getObject(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Encode URL
	url = helpers.encodeURL(url)
	# Create Facebook API URL
	target_url = FACEBOOK_ENDPOINT + '%27' + url + '%27'
	try:
		# Hit Facebook API
		r = requests.get(target_url)
		j = r.json()
		if j['data']:
			return j['data'][0]
		else:
			return { 'error': j['error']['message'] }
	except Exception as e:
		return { 'error': e }


def getShares(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Encode URL
	url = helpers.encodeURL(url)
	# Create Facebook API URL
	target_url = FACEBOOK_ENDPOINT + '%27' + url + '%27'
	try:
		# Hit Facebook API
		r = requests.get(target_url)
		j = r.json()
		if j['data']:
			return { 'share_count': j['data'][0]['share_count'] }
		else:
			return { 'error': j['error']['message'] }
	except Exception as e:
		return { 'error': e }


def getLikes(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Encode URL
	url = helpers.encodeURL(url)
	# Create Facebook API URL
	target_url = FACEBOOK_ENDPOINT + '%27' + url + '%27'
	try:
		# Hit Facebook API
		r = requests.get(target_url)
		j = r.json()
		if j['data']:
			return { 'like_count': j['data'][0]['like_count'] }
		else:
			return { 'error': j['error']['message'] }
	except Exception as e:
		return { 'error': e }


def getComments(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Encode URL
	url = helpers.encodeURL(url)
	# Create Facebook API URL
	target_url = FACEBOOK_ENDPOINT + '%27' + url + '%27'
	try:
		# Hit Facebook API
		r = requests.get(target_url)
		j = r.json()
		if j['data']:
			return { 'comment_count': j['data'][0]['comment_count'] }
		else:
			return { 'error': j['error']['message'] }
	except Exception as e:
		return { 'error': e }


def getEncodedURL(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Encode URL
	url = helpers.encodeURL(url)
	# Create Facebook API URL
	return FACEBOOK_ENDPOINT + '%27' + url + '%27'






from . import helpers
import requests

# Google+ API
GOOGLE_ENDPOINT = "https://plusone.google.com/_/+1/fastbutton?url="

	

def getPlusOnes(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Encode URL
	url = helpers.encodeURL(url)
	# Create Google+ API URL
	target_url = GOOGLE_ENDPOINT + url
	try:
		# Hit Google+ API
		r = requests.get(target_url)
		# Look for a "window.__SSR" key
		if r.text.find("window.__SSR") != -1:
			# Parse count value from response
			window = r.text.find("window.__SSR")
			start = r.text.find("c:", window)
			end = r.text.find(',', start+1)
			key_len = len('c:')
			# Convert pin_count to integer
			plus_count = int(float(r.text[start+key_len:end].strip()))
			return { 'plus_count': plus_count }
		else:
			return { 'error': 'Remember to use http://...' }
	except Exception as e:
		return { 'error': 'Please provide an actual URL. Remember to use http://...' }


def getEncodedURL(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Encode URL
	url = helpers.encodeURL(url)
	# Create Facebook API URL
	return GOOGLE_ENDPOINT + url




from distutils.core import setup

setup(
    name='socialanalytics',
    version='0.3.1',
    author='Michael Stitt',
    author_email='michaelstitt10@hotmail.com',
    packages=['socialanalytics'],
    url='https://github.com/Abundnce10/socialanalytics',
    license='LICENSE.txt',
    description='Insight into how a specific URL performs on a variety of social networks.',
    long_description=open('README').read(),
    install_requires=[
        "requests >= 2.0.0",
    ],
)



from . import helpers
import requests

# Twitter API
TWITTER_ENDPOINT = "http://urls.api.twitter.com/1/urls/count.json?url="


def getShares(url):
	# Remove any URL tracking params
	url = helpers.removeParams(url)
	# Create Twitter API URL
	target_url = TWITTER_ENDPOINT + url
	# Hit Twitter API
	try:
		r = requests.get(target_url)
		j = r.json()
		# Return Count value
		return {'share_count': j['count'] }
	except Exception as e:
		return { 'error': e }
	
